<?php

namespace Noalyss\Forms;
/*
 *   This file is part of NOALYSS.
 *
 *   NOALYSS is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   NOALYSS is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with NOALYSS; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
// Copyright Author Dany De Bontridder danydb@aevalys.eu 31/10/23
/*! 
 * \file
 * \brief Manage the FORM definition
 */

/*!
* \class
* \brief Manage the FORM definition
*/

class Form
{
    protected $form_id;

    public function __construct($form_id)
    {
        $this->form_id = $form_id;

    }

    /**
     * @return mixed
     */
    public function getFormId()
    {
        return $this->form_id;
    }

    /**
     * @param mixed $form_id
     */
    public function setFormId($form_id): Form
    {
        $this->form_id = $form_id;
        return $this;
    }

    /**
     * @brief display the list of forms , with a link to the definition
     */
    public static function display_list()
    {
        global $cn, $g_dir_nform;
        $form_sql = new Form_SQL($cn);
        $a_form_sql = $form_sql->collect_objects(" order by f_title");

        require $g_dir_nform . "/template/form-display_list.php";

    }

    public function display()
    {
        global $g_dir_nform;
        require $g_dir_nform . "/template/form-display.php";
    }

    /**
     * @brief Display FORM definition
     * @param FORM.F_ID int
     */
    public static function form($p_form_id)
    {
        global $gDossier,$g_access, $g_plugin, $g_dir_nform, $cn;

        //-----------------------------------------------------------------------
        $form = new \Noalyss\Forms\Form($p_form_id);
        echo '<FORM METHOD="POST" ACTION="do.php">';
        echo \HtmlInput::request_to_hidden(['ac', 'plugin_code', 'gDossier', 'form_id']);
        $form->display();
        if ($p_form_id > 0) {
            $form_detail = \Noalyss\Forms\Form_Detail_MTable::build($p_form_id, $p_form_id);
            $form_detail->display_table(' where form_id=$1',[$p_form_id]);
            echo '            <div class="form-group">
                <label for="delete">Pour effacer, cocher cette case</label>';
            $checkbox=new \ICheckBox("delete","$p_form_id");
            echo $checkbox->input();
            echo '</div>';
        } else {
            echo '<small class="text-muted">',
            "Il faut d'abord sauver la catégorie de fiches avant de pouvoir ajouter des paramètres",
            '</small>';
            echo \HtmlInput::hidden("new", "1");
        }

        echo '<ul class="aligned-block">';
        echo '<li>';
        echo \HtmlInput::submit("save", "Sauve");
        echo '</li>';
        echo '<li>';
        echo \HtmlInput::button_anchor("Retour", "do.php?" . http_build_query(["ac" => $g_access
                , "plugin_code" => $g_plugin, "gDossier" => $gDossier]));
        echo '</li>';
        echo '</ol>';
        echo '</FORM>';

        if ($p_form_id > 0) { $form_detail->create_js_script(); }
    }

    public function from_array($p_array = [])
    {
        global $cn;
        if (empty($p_array)) {
            $p_array = $_POST;
        }
        $http = new \HttpInput();
        $http->set_array($p_array);
        $obj = new  Form_SQL($cn);
        $obj->setp('f_id', $http->extract("form_id", "number"));
        $obj->setp('f_token', $http->extract("token", "string"));
        $obj->setp('f_title', $http->extract("form_title", "string"));
        $obj->setp('f_description', $http->extract("form_description", "string"));
        $obj->setp('f_url_allow', $http->extract("form_allow", "string"));
        $obj->setp('f_url_success', $http->extract("form_success", "string"));
        $obj->setp('f_url_fail', $http->extract("form_fail", "string"));
        $obj->setp('fiche_def_id', $http->extract("fiche_def", "number"));
        return $obj;
    }

    public function check_form_sql(Form_SQL $form_SQL)
    {
        if ( noalyss_trim($form_SQL->f_token)=="" ||
             noalyss_trim($form_SQL->f_title)=="") {
            throw new \Exception ("Token et le titre sont obligatoires");
        }

    }

    /**
     * @brief save a form ,
     * @param $p_array : index (form_id:f_id
     * , token:f_token
     * ,form_title:f_title
     * ,form_description
     * ,f_description,
     * form_allow:f_url_allow
     * ,form_success:f_url_success
     * ,form_fail:f_url_fail
     * ,fiche_def:fiche_def_id), corresponding     * to the columns of FORM_SQL
     */
    public function save($p_array = [])
    {
        $obj = $this->from_array($p_array);
        try {
            $this->check_form_sql($obj);
            $obj->save();
            $this->form_id=$obj->f_id;
        } catch (\Exception $e) {
                throw $e;
        }

    }


}
